%--------------------------------------------------------------
%     Lorenz 3-variable error estimation.
%     created by Juan Ruiz based on Shu-Chi Yang scripts.
%--------------------------------------------------------------
clear all
close all
set(0,'format','long')
randn('seed',0)

%------------------------------------------------------------
% specify coupled system parameters
%------------------------------------------------------------
a      = 10.0d0;	% standard L63 
par(1) = a;
r      = 28.0d0;	% standard L63
par(2) = r;
b      = 8.0d0/3.d0;	% standard L63
par(3) = b;

%------------------------------------------------------------
% Model and experienet setup
%------------------------------------------------------------
dim=3.0d0;            % specify dimension
h2=0.01d0;            % specify rk4 stepsize 
tskip=500;            % evaluate the error after tskip analysis cycles

%------------------------------------------------------------
% Error estimation setup
%------------------------------------------------------------
bst=8;                 % interval between forecasts


% load arrays
load ../input/analysis.mat

[numstep dim]=size(state);
statef_1=NaN(numstep,dim);
statef_2=NaN(numstep,dim);



for i=1:numstep-2
    %Integrate the ensemble from the analysis
        
        x=statea(i,:);
        %Integrate the model for bst time steps
        for j=1:bst
            xout=stepit('L63eqs',x,par,h2,dim);
            x=xout;    
        end
        statef_1(i+1,:)=x;
        
        %Integrate the model for another bst time steps
        for j=1:bst
            xout=stepit('L63eqs',x,par,h2,dim);
            x=xout;    
        end
        statef_2(i+2,:)=x;


    time(i)=i*bst*h2;
  
end


covmat=cov(statef_1(3:numstep-2,:)-statef_2(3:numstep-2,:));

covmat2=cov(statef_1(3:numstep-2,:)-statea(3:numstep-2,:));

covmat3=cov(statef_1(3:numstep-2,:)-state(3:numstep-2,:));


true_error=statef_1(3:numstep-2,:)-state(3:numstep-2,:);
est_error=statef_1(3:numstep-2,:)-statef_2(3:numstep-2,:);
%Plot the error variance and co-variance as a function of the position in
%the X-Y plane.
%**************************************************************************
%VARIANZA ERRORX-ERRORX COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='TRUE VAR X plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),true_error(:,1),true_error(:,1),[-20 20],2,[-22 22],2);
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/trueerror_varX.png');

%VARIANZA ERRORY-ERRORY COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='TRUE VAR Y plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),true_error(:,2),true_error(:,2),[-20 20],2,[-22 22],2);
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/trueerror_varY.png');

%VARIANZA ERRORZ-ERRORZ COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='TRUE VAR Z plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),true_error(:,3),true_error(:,3),[-20 20],2,[-22 22],2);;
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/trueerror_varZ.png');

%VARIANZA ERRORX-ERRORY COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='TRUE COVAR XY plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),true_error(:,1),true_error(:,2),[-20 20],2,[-22 22],2);
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/trueerror_covarXY.png');

%VARIANZA ERRORX-ERRORZ COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='TRUE COVAR XZ plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),true_error(:,1),true_error(:,3),[-20 20],2,[-22 22],2);
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/trueerror_covarXZ.png');

%VARIANZA ERRORY-ERRORZ COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='TRUE COVAR YZ plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),true_error(:,2),true_error(:,3),[-20 20],2,[-22 22],2);
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/trueerror_covarYZ.png');


%Plot the estimated error variance and co-variance as a function of the position in
%the X-Y plane.
%**************************************************************************
%VARIANZA ERRORX-ERRORX COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='ESTIMATED VAR X plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),est_error(:,1),est_error(:,1),[-20 20],2,[-22 22],2);
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/esterror_varX.png');

%VARIANZA ERRORY-ERRORY COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='ESTIMATED VAR Y plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),est_error(:,2),est_error(:,2),[-20 20],2,[-22 22],2);
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/esterror_varY.png');

%VARIANZA ERRORZ-ERRORZ COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='ESTIMATED VAR Z plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),est_error(:,3),est_error(:,3),[-20 20],2,[-22 22],2);;
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/esterror_varZ.png');

%VARIANZA ERRORX-ERRORY COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='ESTIMATED COVAR XY plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),est_error(:,1),est_error(:,2),[-20 20],2,[-22 22],2);
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/esterror_covarXY.png');

%VARIANZA ERRORX-ERRORZ COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='ESTIMATED COVAR XZ plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),est_error(:,1),est_error(:,3),[-20 20],2,[-22 22],2);
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/esterror_covarXZ.png');

%VARIANZA ERRORY-ERRORZ COMO FUNCION DE LA POSICION EN EL PLANO X-Y.
%variable
titulo='ESTIMATED COVAR YZ plano X-Y'
%... resto de la figura.
[rxy covxy]=correlacion(state(3:numstep-2,1:2),est_error(:,2),est_error(:,3),[-20 20],2,[-22 22],2);
figure
pcolor([-19:2:19],[-21:2:21],covxy);
%caxis([0 1])
title(titulo)
plot_jrcol([-2.5 -1 -0.5 -0.25 -0.1 0.1 0.25 0.5 1 2.5],[32 34 36 37 21 23 25 27 29]);
shading flat
run colorbar
clear aux aux1 aux2 auxiliar
print('-dpng','../output/esterror_covarYZ.png');




