function [R,H,yobs]=DA_init(tin,numstep,p,n,iobs,R0,state,obsgen,obsfile)
%
%  initialize the data assimilation
%  input : 
%  tin - observation interval
%  numstep - number of analysis cycle
%  p   - observation number
%  n   -
%  ios - observation location
%  R0  - observation error variance (diagnal elements of observation error covariance)
%  state - true state
%  obsgen -generate the observation  
%  obsfile - if not generating new observation, load from file  
%  Shu-Chih Yang 2005
%  
%
fprintf(1,'\n');

if( nargin >= 8)
   % load observation from obsfile
   R0_in=R0;
   if (obsgen==0);
     %% use the default observation file
     obsfile='../input/obs1_3dvar.mat';
     disp(['Init DA: Load observations from file, ',obsfile])
   end
else
  obsgen=1;
end

In=eye(3,3);

%   create the observation error covariance
R=R0*eye(p);
%disp(['Observation error covariance '])
%for i=1:p
%   fprintf(1,'%7.5f %7.5f %7.5f\n',R(:,i));
%end
%fprintf(1,'\n');

%   create the observation operator 
%   (in this case, obsevation locations are on the model grid points)
H=zeros(p,n);
for i=1:p
    H(i,iobs(i))=1.d0;
end

yobs=zeros(numstep,p);
if (obsgen <= 0)
%load the observations
    %load obs1_3dvar.mat R0 numstep_lng yobs0;
    eval(['load ../input/',obsfile,' R0 numstep_lng yobs0;'])
    if (R0 ~= R0_in)
      disp(['Obs error from file are not consistent with the input obs error!!!'])
      return
    end
    if (numstep_lng < numstep)
      disp(['Not enough observations for this run'])
      disp(['total length in this file :',num2str(numstep_lng)])
    end
    for i=1:p
        yobs(1:numstep,i)=yobs0(1:numstep,iobs(i));
    end
else
% generate observations
     eostd=sqrt(R0);
     erro=eostd*randn(numstep,p);
     randn('seed',0);
     for i=1:numstep
        %eo=eostd*randn(1,p);
        for j=1:p
            %yobs(i,j)=state(i,iobs(j))+eo(j);
            yobs(i,j)=state(i,iobs(j))+erro(i,j);
        end
     end
end
