function [R,B,H,yobs]=DA_init(tin,numstep,p,n,iobs,R0,state,obsgen,obsfile)
%
%  initialize the data assimilation
%  input : 
%  tin - observation interval
%  numstep - number of analysis cycle
%  p   - observation number
%  n   -
%  ios - observation location
%  R0  - observation error variance (diagnal elements of observation error covariance)
%  state - true state
%  obsgen -generate the observation  
%  obsfile - if not generating new observation, load from file  
%  Shu-Chih Yang 2005
%  
%
fprintf(1,'\n');

if( nargin >= 8)
   % load observation from obsfile
   R0_in=R0;
   if (obsgen==0);
     %% use the default observation file
     obsfile='../input/obs1_3dvar.mat';
     disp(['Init DA: Load observations from file, ',obsfile])
   end
else
  obsgen=1;
end

In=eye(3,3);
%   load in the B for 3D-Var
xyz='xyz';
Bfile=['B',xyz(iobs),'_bst',num2str(tin),'.mat'];
eval(['load ../input/',Bfile,' B;'])  
disp(['Load Bfile from ', Bfile])
disp(['Background error covariance '])
for i=1:3
   fprintf(1,'%7.5f %7.5f %7.5f\n',B(:,i));
end
fprintf(1,'\n');

%   create the observation error covariance
R=R0*eye(p);
disp(['Observation error covariance '])
for i=1:p
   fprintf(1,'%7.5f %7.5f %7.5f\n',R(:,i));
end
fprintf(1,'\n');

%   create the observation operator 
%   (in this case, obsevation locations are on the model grid points)
H=zeros(p,n);
for i=1:p
    H(i,iobs(i))=1.;
end

%H=[1 1 1; 1 -1 0;-1 0 1];



yobs=zeros(numstep,p);
if (obsgen <= 0)
%load the observations
    %load obs1_3dvar.mat R0 numstep_lng yobs0;
    eval(['load ../input/',obsfile,' R0 numstep_lng yobs0;'])
    if (R0 ~= R0_in)
      disp(['Obs error from file are not consistent with the input obs error!!!'])
      return
    end
    if (numstep_lng < numstep)
      disp(['Not enough observations for this run'])
      disp(['total length in this file :',num2str(numstep_lng)])
    end
    for i=1:p
        yobs(1:numstep,i)=yobs0(1:numstep,iobs(i));
    end
else
% generate observations
% En este caso las observaciones se generan como 
% una perturbacion con respecto a la evolucion "real" del sistema.
% esta perturbacion es al azar, pero su amplitud esta realcionada con R0 que es
% el error de las observaciones, es decir que a mayor R0 mayor es el error de las 
% observaciones con respecto al estado real del sistema.

     eostd=sqrt(R0);
     for i=1:numstep
        eo=eostd*randn(1,p);
        for j=1:p
            yobs(i,j)=state(i,iobs(j))+eo(j);
        end
%     yobs(i,1)=state(i,1)+state(i,2)+state(i,3)+eo(1);
%     yobs(i,2)=state(i,1)-state(i,2)+eo(2);
%     yobs(i,3)=state(i,3)-state(i,1)+eo(3);
     end


end
