function [xa]=RUN_3DVAR(yo,xb,p,dim,H,R,B)
%---------------------------------------------
%  apply 3DVAR to update analysis state 
%  weighting matrix in 3DVAR is
%      
%       W=B*H^T(R+H*B*H^T)^-1
%       xa-xb=W*d
%  
%  input: 
%       p - total observations
%       yo(1,p) - observations
%       xb(1,dim) - background state
%       B - background error covariance
%       R - observation error covariance
%  output:
%       xa(1:dim) - analysis state
%
%  Shu-Chih Yang, 2006
%---------------------------------------------

% innovation vector (obs-background)
d=yo(1,1:p)'-H*xb(1,1:dim)';

%calculate the analysis increment using 3DVAR
dxa=B*H'*inv((R+H*B*H'))*d;
    
%updating analysis state
xa=xb+dxa';
