%--------------------------------------------------------------
%     Lorenz 3-variable system with data assimilation
%     DA scheme: 3D-Var component
%     created by Shu-Chih Yang, 2005
%--------------------------------------------------------------
clear all
close all
% specify coupled system parameters
a      = 10;		% standard L63 
par(1) = a;
r      = 28;		% standard L63
par(2) = r;
b      = 8./3;		% standard L63
par(3) = b;

% Model and experienet setup
dim=3;            % specify dimension
h2=0.01;          % specify rk4 stepsize 
numtrans=600;     % specify transient time
numstep=2000;     % specify integration time
x0=[8 0 30];      % specify initial conditions

% Data assimilation setup
dx0 = [5. 5. 5.]; % initial perturbation
R0= 2.0;          % the variance of observation error
iobs=[1;2;3];     % observation index (location)
bst=8;            % assimilation/observation interval

% declare arrays
p=length(iobs);   % no. of observation for one assimilation cycle
H=zeros(p,dim);   % initialize observation operator
yobs=zeros(numstep,p); % array to load observations
obsgen=1;        % obsgen (1: generate new obs, 0: load from default file, -1: load from given file)

% Input/output files
%fid=fopen('../output/states.dat','w');

% remove transient time
x=x0;
for i=1:numtrans
    xout=stepit('L63eqs',x,par,h2,dim);
    x=xout;
end

% redefine initial conditions
x0 = x;
% 
% control run without assimilation
% traj: true trajectory
% state: true state 
% statep: perturbed state (no assimilation)
% errp: error variance

x=x0;          % initial true state
xp=x+dx0;      % initial perturbed state
q=1;
for i=1:numstep
    for j=1:bst
        xout=stepit('L63eqs',x,par,h2,dim);
        x=xout;
        xpout=stepit('L63eqs',xp,par,h2,dim);
        xp=xpout;    
        traj(q,:)=x;
        q=q+1;
    end
    state(i,:)=x;
    statep(i,:)=xp;
    errp(i)=sqrt(( (statep(i,1)-state(i,1)).^2+ (statep(i,2)-state(i,2)).^2 +(statep(i,3)-state(i,3)).^2)/3.);
end

% initialize the matrix operator for 3D-Var
[R,B,H,yobs]=DA_init(bst,numstep,p,dim,iobs,R0,state,obsgen);

% Experiments with 3D-Var

x=x0+dx0;       % initial perturbed state
for i=1:numstep
    
    for j=1:bst
        xout=stepit('L63eqs',x,par,h2,dim);
        x=xout;    
    end
    time(i)=i*bst*h2;

    % saving forecast (background) state
    statef(i,:)=x;
    
    % Data assimilation 
    [x]=RUN_OI(yobs(i,:),x,p,dim,H,R,B);    
    
    %saving analysis state
    statea(i,:)=x;
    
    %calculate the root mean square error
    
    err(i) =sqrt( ( (statea(i,1)-state(i,1)).^2+ (statea(i,2)-state(i,2)).^2 +(statea(i,3)-state(i,3)).^2)/3.);
    errf(i)=sqrt( ( (statef(i,1)-state(i,1)).^2+ (statef(i,2)-state(i,2)).^2 +(statef(i,3)-state(i,3)).^2)/3.);
    %fprintf(fid,'%7.3f %7.3f %7.3f %7.3f %7.3f %7.3f %7.3f %7.3f %7.3f %7.3f %7.3f %7.3f \n',state(i,:),statea(i,:),yobs(i,:),statef(i,:));
end
% mean RMS analysis/background error
rmse_a=mean(err(500:numstep));
rmse_f=mean(errf(500:numstep));
rmse=mean(errp(500:numstep));
%fprintf(1,'No assimilation, Mean RMSE= %g \n',rmse)
fprintf(1,'Obseveraion error= %g \n',sqrt(R0))
fprintf(1,'Number of DA cycles= %g \n',numstep)
fprintf(1,'Mean background RMSE= %g \n',rmse_f)
fprintf(1,'Mean analysis RMSE= %g \n',rmse_a)

ind=[1:500];
% plot the error
DAerrplt(time(ind),err(ind),rmse_a,sqrt(R0),iobs);
print -f1 -dpng ../output/output1.png;
% plot the states vs. obs
stateplt(time(ind),yobs(ind,1),state(ind,1),statea(ind,1),'X')
print -f1 -dpng ../output/output2.png;

save('../output/analysis.mat','statea','statef','state');
